==> qt-creator-opensource-src-4.0.1.tar.gz: qt-creator-opensource-src-4.0.1/src/libs/clangbackendipc/projectpartsdonotexistmessage.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "projectpartsdonotexistmessage.h"

#include <QDataStream>
#include <QDebug>

#include <ostream>

namespace ClangBackEnd {

ProjectPartsDoNotExistMessage::ProjectPartsDoNotExistMessage(const Utf8StringVector &projectPartIds)
    : projectPartIds_(projectPartIds)
{
}


const Utf8StringVector &ProjectPartsDoNotExistMessage::projectPartIds() const
{
    return projectPartIds_;
}

QDataStream &operator<<(QDataStream &out, const ProjectPartsDoNotExistMessage &message)
{
    out << message.projectPartIds_;

    return out;
}

QDataStream &operator>>(QDataStream &in, ProjectPartsDoNotExistMessage &message)
{
    in >> message.projectPartIds_;

    return in;
}

bool operator==(const ProjectPartsDoNotExistMessage &first, const ProjectPartsDoNotExistMessage &second)
{
    return first.projectPartIds_ == second.projectPartIds_;
}

QDebug operator<<(QDebug debug, const ProjectPartsDoNotExistMessage &message)
{
    debug.nospace() << "ProjectPartDoesNotExistMessage(";

    debug.nospace() << message.projectPartIds_;

    debug.nospace() << ")";

    return debug;
}

void PrintTo(const ProjectPartsDoNotExistMessage &message, ::std::ostream* os)
{
    QString output;
    QDebug debug(&output);

    debug << message;

    *os << output.toUtf8().constData();
}


} // namespace ClangBackEnd

==> qt-creator-opensource-src-4.4.0.tar.gz: qt-creator-opensource-src-4.4.0/src/libs/clangbackendipc/projectpartsdonotexistmessage.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "projectpartsdonotexistmessage.h"

#include <QDebug>

#include <ostream>

namespace ClangBackEnd {

QDebug operator<<(QDebug debug, const ProjectPartsDoNotExistMessage &message)
{
    debug.nospace() << "ProjectPartDoesNotExistMessage(";

    debug.nospace() << message.projectPartIds();

    debug.nospace() << ")";

    return debug;
}

std::ostream &operator<<(std::ostream &os, const ProjectPartsDoNotExistMessage &message)
{
    os << "("
       << message.projectPartIds()
       << ")";

    return os;
}

} // namespace ClangBackEnd
